var db = require('../../config/db');
var moment = require('moment');
var fcm = require('fcm-notification');

var Notification = function (data) {
    this.title = data.title;
    this.description = data.description;
    this.created_on = new Date();
};

Notification.notificationRead = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        var queryString = "UPDATE tg_customer_notification SET status = ? WHERE customer_id = ?"
        var filter = [1, postData.sfa_app_user_id];
        
        console.log('queryString',queryString);
        console.log('filter',filter);
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                console.log('res',res);
                resolve(res);
            }
        });
    });
};


Notification.notificationIcon = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        var queryString = "SELECT type,CONCAT('" + postData.image_path + "', tg_master_icon.image_url) as image_url FROM ?? WHERE status = ?";        
        var filter = ["tg_master_icon", 1];
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                resolve(res);
            }
        });
    });
};


Notification.getUnReadUserNotificationCount = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        var queryString = "SELECT IF(COUNT(id),COUNT(id),0) as TotalNotificationUnReadCount FROM ?? WHERE status = ? AND customer_id = ?;"
        var filter = ["tg_customer_notification", 0, postData.sfa_app_user_id];
        
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                var count = 0;
                if(res.length){
                    count = res[0].TotalNotificationUnReadCount;
                }
                resolve(count);
            }
        });
    });
};


Notification.GP_getUserTodayNotification = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        // s3 link updated
        var queryString = "SELECT tg_customer_notification.*, IF(tg_customer_notification.image != '' , CONCAT('"+postData.image_app_path+"', tg_customer_notification.image), '' ) as image_app_path  FROM tg_customer_notification LEFT JOIN tg_customer ON tg_customer.id = tg_customer_notification.customer_id  WHERE tg_customer_notification.customer_id = ? AND DATE(tg_customer_notification.created_on) = ? AND tg_customer_notification.deleted  = ?  ORDER BY tg_customer_notification.ID DESC "
        var filter = [postData.sfa_app_user_id, moment(new Date()).format('YYYY-MM-DD'), 0];
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                resolve(res);
            }
        });
    });
};


Notification.GP_getUserYesterdayNotification = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        // s3 link updated
        var queryString = "SELECT tg_customer_notification.*, IF(tg_customer_notification.image != '' , CONCAT('"+postData.image_app_path+"', tg_customer_notification.image), '' ) as image_app_path FROM tg_customer_notification LEFT JOIN tg_customer ON tg_customer.id = tg_customer_notification.customer_id  WHERE tg_customer_notification.customer_id = ? AND DATE(tg_customer_notification.created_on) = ? AND tg_customer_notification.deleted  = ?  ORDER BY tg_customer_notification.ID DESC "
        var filter = [postData.sfa_app_user_id, moment(new Date()).subtract(1, "days").format('YYYY-MM-DD'), 0];
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                resolve(res);
            }
        });
    });
};



Notification.GP_getUserNotification = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        // s3 link updated
        var queryString = "SELECT tg_customer_notification.* , IF(tg_customer_notification.image != '' , CONCAT('"+postData.image_app_path+"', tg_customer_notification.image), '' ) as image_app_path FROM tg_customer_notification LEFT JOIN tg_customer ON tg_customer.id = tg_customer_notification.customer_id  WHERE tg_customer_notification.customer_id = ? AND DATE(tg_customer_notification.created_on) < ? AND tg_customer_notification.deleted  = ? ORDER BY tg_customer_notification.ID DESC  limit ? OFFSET ?;";
        var filter = [postData.sfa_app_user_id, moment(new Date()).subtract(2, "days").format('YYYY-MM-DD'),0, parseInt(postData.limit), parseInt(postData.start)];
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                resolve(res);
            }
        });
    });
};



// for sfa

Notification.getUnReadUserNotificationCount_salesUser = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        var queryString = "SELECT IF(COUNT(id),COUNT(id),0) as TotalNotificationUnReadCount FROM ?? WHERE status = ? AND user_id = ?;"
        var filter = ["tg_user_notification", 0, postData.sfa_app_user_id];
        
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                var count = 0;
                if(res.length){
                    count = res[0].TotalNotificationUnReadCount;
                }
                resolve(count);
            }
        });
    });
};


Notification.GP_getUserTodayNotification_salesUser = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        // s3 link updated
        var queryString = "SELECT tg_user_notification.*, IF(tg_user_notification.image != '' , CONCAT('"+postData.image_app_path+"', tg_user_notification.image), '' ) as image_app_path  FROM tg_user_notification WHERE tg_user_notification.user_id = ? AND DATE(tg_user_notification.created_on) = ? AND tg_user_notification.deleted  = ?  ORDER BY tg_user_notification.ID DESC "
        var filter = [postData.sfa_app_user_id, moment(new Date()).format('YYYY-MM-DD'), 0];
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                resolve(res);
            }
        });
    });
};


Notification.GP_getUserYesterdayNotification_salesUser = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        // s3 link updated
        var queryString = "SELECT tg_user_notification.*, IF(tg_user_notification.image != '' , CONCAT('"+postData.image_app_path+"', tg_user_notification.image), '' ) as image_app_path FROM tg_user_notification WHERE tg_user_notification.user_id = ? AND DATE(tg_user_notification.created_on) = ? AND tg_user_notification.deleted  = ?  ORDER BY tg_user_notification.ID DESC "
        var filter = [postData.sfa_app_user_id, moment(new Date()).subtract(1, "days").format('YYYY-MM-DD'), 0];
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                resolve(res);
            }
        });
    });
};



Notification.GP_getUserNotification_salesUser = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        // s3 link updated
        var queryString = "SELECT tg_user_notification.* , IF(tg_user_notification.image != '' , CONCAT('"+postData.image_app_path+"', tg_user_notification.image), '' ) as image_app_path FROM tg_user_notification WHERE tg_user_notification.user_id = ? AND DATE(tg_user_notification.created_on) < ? AND tg_user_notification.deleted  = ? ORDER BY tg_user_notification.ID DESC  limit ? OFFSET ?;";
        var filter = [postData.sfa_app_user_id, moment(new Date()).subtract(2, "days").format('YYYY-MM-DD'),0, parseInt(postData.limit), parseInt(postData.start)];
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                resolve(res);
            }
        });
    });
};

Notification.notificationRead_salesUser = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        var queryString = "UPDATE tg_user_notification SET status = ? WHERE user_id = ?"
        var filter = [1, postData.sfa_app_user_id];
        
        console.log('queryString',queryString);
        console.log('filter',filter);
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                console.log('res',res);
                resolve(res);
            }
        });
    });
};



Notification.checkUserNotification_salesUser = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        var queryString = "SELECT id FROM ?? WHERE user_id = ? AND id = ?;"
        var filter = ["tg_user_notification", postData.sfa_app_user_id, postData.notification_id];
        
        // console.log('queryString',queryString);
        // console.log('filter',filter);
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                console.log('res',res);
                resolve(res);
            }
        });
    });
};

Notification.markReadNotification_salesUser = function (postData, result) {
    
    return new Promise(function (resolve, reject) {
        
        var queryString = "UPDATE tg_user_notification SET status = ? WHERE user_id = ? AND id = ?;"
        var filter = [1, postData.sfa_app_user_id, postData.notification_id];
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                resolve(res);
            }
        });
    });
};



Notification.checkUserNotification = function (postData) {
    
    return new Promise(function (resolve, reject) {
        
        var queryString = "SELECT id FROM ?? WHERE customer_id = ? AND id = ?;"
        var filter = ["tg_customer_notification", postData.sfa_app_user_id, postData.notification_id];
        
        // console.log('queryString',queryString);
        // console.log('filter',filter);
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                console.log('res',res);
                resolve(res);
            }
        });
    });
};

Notification.markReadNotification = function (postData, result) {
    
    return new Promise(function (resolve, reject) {
        
        var queryString = "UPDATE tg_customer_notification SET status = ? WHERE customer_id = ? AND id = ?;"
        var filter = [1, postData.sfa_app_user_id, postData.notification_id];
        
        db.query(queryString, filter, function (err, res) {
            if (err) {
                console.log("error: ", err);
                return reject(err);
            }
            else {
                resolve(res);
            }
        });
    });
};



module.exports = Notification;